<?php

namespace Bixo\Chat\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Bixo\Chat\Actions\ChatExim;
use Bixo\Chat\Http\Requests\ChatEximRequest;

/**
 * Admin web controller class.
 */
class ChatEximController extends BaseController
{
    /**
     * Action controller function for chat.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ChatEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = ChatExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('chat:chat.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('chat/chat/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('chat/chat/' . $exim))
                ->redirect();
        }
    }
}
